@@ -21,7 +21,7 @@ function app_init(){
 
 function app_server(){
   var server=require('./lib/bin/server');
-  console.log(__dirname);
+  console.log("nylon-dir::"+__dirname);
   server.serve(__dirname);
 }
 
