@@ -38,7 +38,7 @@ module.exports = function (nylon_path) {
 
     /** load express module */
 
-     console.log(work_dir);
+     console.log("work_dir::"+work_dir);
     fscan.scan(work_dir + "/lib/modules", ".js", false, function (err, modelues) {
       //  for (var i = 0; i < modelues.length; i++) {
          //   console.log("Load Module :: " + modelues[i]);
